@@ -55,7 +55,7 @@ BOT = None
 class CLIBot:
     """ Conversation manager intended to interact with the user on the command line, but can be used by other plugins/
 
-    >>> CLIBot(bots='parul,pattern'.split(','), num_top_replies=1, semantics=1.0).reply('Hi')
+    >>> CLIBot(bots='parul,pattern'.split(','), num_top_replies=1).reply('Hi')
     'Hello!'
     """
     bot_names = []
@@ -131,7 +131,7 @@ class CLIBot:
                 bot_replies = bot.reply(statement, context=context)
                 log.info("{bot.__name__} replies: {bot_replies}")
             except TypeError as e:
-                log.warn(f"TypeError: bot.reply probably got an unexpected keyword argument 'context': {e}")
+                log.warning(f"TypeError: bot.reply probably got an unexpected keyword argument 'context': {e}")
                 bot_replies = bot.reply(statement)
             except Exception as e:
                 log.error(f'Error trying to run {bot.__self__.__class__}.reply("{statement}", context={context})')
@@ -175,7 +175,7 @@ def run_bot():
         BOT = CLIBot(
             bots=constants.args.bots,
             num_top_replies=constants.args.num_top_replies,
-            semantics=constants.args.semantics,
+            semantic=constants.args.semantic,
             sentiment=constants.args.sentiment,
             spell=constants.args.spell)
     if constants.args.persist:
