@@ -11,7 +11,7 @@ import configargparse
 from environment import Environment
 import django.conf
 
-from . import __version__
+from qary import __version__
 
 from qary.etl.fileutils import basename, url_filename, path_filename
 
@@ -38,21 +38,27 @@ EXIT_COMMANDS = set('exit quit bye goodbye cya'.split())
 
 # TODO: put this in etl/models.py or data/models.py for storage in Django ORM database
 LARGE_FILES = {
+    'wikipedia_titles': dict(
+        url='https://tan.sfo2.digitaloceanspaces.com/midata/public/corpora/enwiki-latest-all-titles-in-ns0.gz',
+        path=Path(DATA_DIR, 'corpora', 'wikipedia', 'enwiki-latest-all-titles-in-ns0.gz')),
     'squad_dev': dict(
         url='https://rajpurkar.github.io/SQuAD-explorer/dataset/dev-v2.0.json',
-        path=os.path.join(DATA_DIR, 'training_sets', 'squad', 'dev-v2.0.json')),
+        path=Path(DATA_DIR, 'training_sets', 'squad', 'dev-v2.0.json')),
     'squad': dict(
         url='https://rajpurkar.github.io/SQuAD-explorer/dataset/train-v2.0.json',
-        path=os.path.join(DATA_DIR, 'training_sets', 'squad', 'train-v2.0.json')),
+        path=Path(DATA_DIR, 'training_sets', 'squad', 'train-v2.0.json')),
     'floyd': dict(
-        url='https://tan.sfo2.cdn.digitaloceanspaces.com/midata/public/corpora/floyd.pkl',
+        url='https://tan.sfo2.digitaloceanspaces.com/midata/public/corpora/wikipedia/floyd.pkl',
         path=Path(DATA_DIR, 'corpora', 'wikipedia', 'floyd.pkl')),
     'wikipedia_articles': dict(
-        url='https://tan.sfo2.cdn.digitaloceanspaces.com/midata/public/corpora/articles_with_keywords.pkl',
+        url='https://tan.sfo2.digitaloceanspaces.com/midata/public/corpora/wikipedia/articles_with_keywords.pkl',
         path=Path(DATA_DIR, 'corpora', 'wikipedia', 'articles_with_keywords.pkl')),
     'albert-large-v2': dict(
-        url='https://tan.sfo2.cdn.digitaloceanspaces.com/midata/public/models/qa/articles_with_keywords.pkl',
+        url='https://tan.sfo2.digitaloceanspaces.com/midata/public/models/qa/albert-large-v2-0.2.0.zip',
         path=Path(DATA_DIR, 'models', 'qa', 'albert-large-v2-0.2.0.zip')),
+    'bert-base-cased': dict(
+        url='https://tan.sfo2.digitaloceanspaces.com/midata/public/models/qa/bert-base-cased-0.2.0.zip',
+        path=Path(DATA_DIR, 'models', 'qa', 'bert-base-cased-0.2.0.zip')),
 }
 tmp_large_files = {}
 for name, meta in LARGE_FILES.items():
@@ -83,7 +89,7 @@ DEFAULT_CONFIG = {
     'semantic_score': '.5',
     'debug': True,
     'wiki_title_max_words': 4,
-    'score_weights': '{"spell": .25, "sentiment": .25, "semantics": .5}',
+    'score_weights': '{"spell": .25, "sentiment": .25, "semantic": .5}',
     'qa_model': 'albert-large-v2-0.2.0',
 }
 DEFAULT_CONFIG.update(env.parsed)
@@ -229,14 +235,14 @@ def parse_args(args):
         '--score_weights',
         default=DEFAULT_CONFIG['score_weights'],
         dest="score_weights",
-        help='Dictionary of weights: {"spell": .5, "sentiment": .5, "semantics": .5}',
+        help='Dictionary of weights: {"spell": .5, "sentiment": .5, "semantic": .5}',
         type=str,
         metavar="DICT_STR")
     parser.add_argument(
-        '--semantics',
+        '--semantic',
         type=float,
         default=1.0,
-        dest='semantics',
+        dest='semantic',
         metavar='FLOAT',
         help='set weight of the semantic quality score')
     parser.add_argument(
