@@ -6,7 +6,7 @@ from pathlib import Path
 from elasticsearch import Elasticsearch
 import wikipediaapi
 from slugify import slugify
-from .. import constants
+from qary import constants
 
 try:
     client = Elasticsearch()
