@@ -8,8 +8,8 @@ from tqdm import tqdm
 import yaml
 
 # from .spacy_language_model import nlp
-from ..constants import DATA_DIR, STOPWORDS, DEFAULT_GLOSSARY_DOMAINS
-from ..spacy_language_model import nlp
+from qary.constants import DATA_DIR, STOPWORDS, DEFAULT_GLOSSARY_DOMAINS
+from qary.spacy_language_model import nlp
 # from .etl.yml import find_hashtags
 
 import logging
