@@ -1,18 +1,15 @@
-# make sure you `pip install --upgrade git+https://github.com/lucasdnd/Wikipedia.git`
 import os
 import time
 import csv
 import gzip
 import copy
-# from queue import Queue
 
 from tqdm import tqdm
 import pandas as pd
 from wikipediaapi import Wikipedia
 
-from .. import constants
-from ..spacy_language_model import load
-from .vectors import phrase_to_vec
+from qary import constants
+from qary.spacy_language_model import load
 
 import logging
 log = logging.getLogger(locals().get('__name__', ''))
@@ -47,7 +44,7 @@ class WikiIndex():
             csv_writer = csv.writer(fout)
             csv_writer.writerow(['page_title'] + [f'x{i}' for i in range(300)])
             for i, s in tqdm(enumerate(self.df_titles.index.values[start:]), total=total):
-                vec = [s] + phrase_to_vec(str(s))  # s can sometimes (rarely) be a float because of pd.read_csv (df_titles)
+                vec = [s] + list(nlp(str(s)).vector)  # s can sometimes (rarely) be a float because of pd.read_csv (df_titles)
                 vec_batch.append(vec)
                 if not (i % 1000) or i == total - 1:
                     csv_writer.writerows(vec_batch)
