@@ -7,12 +7,13 @@ import re
 
 class Bot:
     def reply(self, statement):
-        """ Chatbot "main" function to respond to a user command or statement
+        r""" Chatbot "main" function to respond to a user command or statement
 
-        >>> reply('Hi')[0][1]
-        Hello!
-        >>> len(reply('Hey Mycroft!'))
-        4
+        >>> bot = Bot()
+        >>> bot.reply('Hi')[0][1]
+        'Hello!'
+        >>> len(bot.reply('Hey Mycroft!'))
+        5
         """
         responses = []
         match = re.match(r'\b(hi|hello|hey)\b(.*)', statement.lower())
