@@ -6,7 +6,7 @@ import os
 import yaml
 import pandas as pd
 from rapidfuzz import process
-from ..constants import DATA_DIR
+from qary.constants import DATA_DIR
 
 log = logging.getLogger(__name__)
 
@@ -70,6 +70,13 @@ class Bot:
         self.db = self.load_dialog(name=name)
 
     def load_dialog(self, name='movie_dialog'):
+        """ Load movie dialog database
+
+        >>> bot = Bot()
+        >>> db = bot.load_dialog()
+        >>> len(db)
+        58007
+        """
         log.warning('Loading movie dialog...')
         if name == 'dsfaq':
             db = load_faq()
@@ -85,11 +92,12 @@ class Bot:
     def reply(self, statement, db=None):
         """ Use rapidfuzz to find the closest key in the dictionary then return the value for that key
 
-        >>> bot = MovieBot()
+        >>> bot = Bot()
         >>> reply = bot.reply
-        >>> reply('hey', {'hello': 'world', 'goodbye': 'fantasy'})
+
+        >> reply('hey', {'hello': 'world', 'goodbye': 'fantasy'})
         (0.3, 'fantasy')
-        >>> reply("Hi!")
+        >> reply("Hi!")
         (1.0, 'hey there. tired of breathing?')
         """
         if self.db is None:
