@@ -59,7 +59,7 @@ def add_hunspell_pipe(model):
 def load(lang=None):
     """ Load the specified language model or the small English model, if none specified
 
-    >>> load_spacy_model()  # doctest: +ELLIPSIS
+    >>> load()  # doctest: +ELLIPSIS
     <spacy.lang.en.English object at ...
     """
     global nlp, UNKNOWN_WORDVEC
