@@ -3,7 +3,7 @@ import pytest  # noqa
 import pandas as pd
 
 from qary.skills.qa_bots import Bot
-from qary.etl.qa_datasets import get_bot_accuracies
+from qary.qa.qa_datasets import get_bot_accuracies
 
 import logging
 
